@@ -38,6 +38,15 @@ def get_pairs(symbols_per_exchange, show_all=True):
     return sorted(pairs)
 
 
+def get_pairs_ex(symbols_per_exchange):
+    pairs = dict()
+    for i in symbols_per_exchange:
+        for _, b in i.items():
+            for c, d in b["pairs"]:
+                pairs[c + d] = dict(token=c, pair=d)
+    return pairs
+
+
 def get_coin_tokens(symbols_per_exchange, show_all=False):
     tokens = set()
     for i in symbols_per_exchange:
