@@ -80,7 +80,12 @@ class ExchangeOpenOrdersOutputSchema(Schema):
     def post_dump_each(self, data):
         data["total"] = data["price"] * data["amount"]
 
-        token_pair = pairs[data["symbol"]]
+        try:
+            token_pair = pairs[data["symbol"]]
+        except KeyError:
+            # Not supported - Must be added in project settings
+            return
+
         data["coin_token"] = token_pair["token"]
         data["pair"] = token_pair["pair"]
 
@@ -141,7 +146,7 @@ class ExchangeOpenOrdersOutputSchema(Schema):
             ] - 100
             break
 
-        if "distance" in data:
+        if "distance" in data and "position" in data:
             data["status"] = data["distance"] < data["position"]
 
     @post_dump(pass_many=True)
