@@ -7,7 +7,6 @@ __license__ = "GPL"
 __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
-
 # Exchanges
 BINANCE = "binance"
 BINANCE_DEX = "binance_dex"
@@ -28,7 +27,6 @@ KUCOIN = "kucoin"
 COINBASE_PRO = "coinbase_pro"
 LIQUID = "liquid"
 
-
 EXCHANGES = [
     BINANCE,
     BINANCE_DEX,
@@ -50,7 +48,6 @@ EXCHANGES = [
     LIQUID,
 ]
 
-
 SYMBOLS_PER_EXCHANGE = []
 
 # Binance
@@ -79,6 +76,8 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("UNI", "BTC"),
                 ("DOT", "USDT"),
                 ("DOT", "BTC"),
+                ("ICP", "USDT"),
+                ("ICP", "BTC"),
                 ("BNB", "USDT"),
                 ("BNB", "BTC"),
                 ("ICX", "USDT"),
@@ -90,8 +89,11 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("XTZ", "USDT"),
                 ("LTO", "USDT"),
                 ("LTO", "BTC"),
+                ("LTO", "BUSD"),
                 ("FTM", "USDT"),
                 ("FTM", "BTC"),
+                ("ALGO", "USDT"),
+                ("ALGO", "BTC"),
                 ("ONT", "USDT"),
                 ("HBAR", "USDT"),
                 ("HBAR", "BTC"),
@@ -99,6 +101,7 @@ SYMBOLS_PER_EXCHANGE.append(
                 ("SNX", "BTC"),
                 ("RLC", "USDT"),
                 ("RLC", "BTC"),
+                ("BUSD", "USDT"),
             ],
         }
     }
@@ -175,19 +178,6 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
-# Bitmax
-SYMBOLS_PER_EXCHANGE.append(
-    {
-        BITMAX: {
-            "pairs": [],
-            "single_request": True,
-        }
-    }
-)
-
-# IDEX
-SYMBOLS_PER_EXCHANGE.append({IDEX: {"pairs": []}})
-
 # OKCoin
 SYMBOLS_PER_EXCHANGE.append(
     {
@@ -214,9 +204,37 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
+# Uphold
+SYMBOLS_PER_EXCHANGE.append(
+    {
+        UPHOLD: {
+            "pairs": [
+                ("BTC", "USD"),
+                ("ETH", "USD"),
+                ("LTC", "USD"),
+            ]
+        }
+    }
+)
+
+# EMPTY EXCHANGES (LOW VOLUME) #######
+
+# IDEX
+SYMBOLS_PER_EXCHANGE.append({IDEX: {"pairs": []}})
+
 # Coinbene
 SYMBOLS_PER_EXCHANGE.append({COINBENE: {"pairs": []}})
 
+# Bitmax
+SYMBOLS_PER_EXCHANGE.append(
+    {
+        BITMAX: {
+            "pairs": [],
+            "single_request": True,
+        }
+    }
+)
+
 # Hotbit
 SYMBOLS_PER_EXCHANGE.append(
     {
@@ -237,26 +255,11 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
-# Uphold
-SYMBOLS_PER_EXCHANGE.append(
-    {
-        UPHOLD: {
-            "pairs": [
-                ("BTC", "USD"),
-                ("ETH", "USD"),
-                ("LTC", "USD"),
-            ]
-        }
-    }
-)
-
 # Binance DEX
 SYMBOLS_PER_EXCHANGE.append(
     {
         BINANCE_DEX: {
-            "pairs": [
-                ("LTO", "BNB"),
-            ],
+            "pairs": [],
             "single_request": True,
         }
     }
@@ -282,7 +285,6 @@ SYMBOLS_PER_EXCHANGE.append(
     }
 )
 
-
 EXCHANGES_AND_PAIRS_OF_REFERENCE = {
     "BTC": {
         "pair": "USDT",
@@ -319,20 +321,12 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
-    "USDC": {
+    "LTO": {
         "pair": "USDT",
         "name": BINANCE,
-        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC", "BUSD"]},
     },
-    "USDT": {
-        "pair": "USD",
-        "name": OKCOIN,
-    },
-    "DAI": {
-        "pair": "USD",
-        "name": COINBASE_PRO,
-    },
-    "LTO": {
+    "ICP": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
@@ -341,6 +335,12 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
+    },
+    "ALGO": {
+        "pair": "USDT",
+        "name": BINANCE,
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
     "EWT": {
         "pair": "USDT",
@@ -355,26 +355,31 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
     },
     "KNC": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
     },
     "AAVE": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
     },
     "UNI": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
     },
     "REN": {
         "pair": "USDT",
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
+        "is_defi": True,
     },
     "DOT": {
         "pair": "USDT",
@@ -421,8 +426,32 @@ EXCHANGES_AND_PAIRS_OF_REFERENCE = {
         "name": BINANCE,
         "market_depth": {"exchange": BINANCE, "pairs": ["USDT", "BTC"]},
     },
+    "USDC": {
+        "pair": "USDT",
+        "name": BINANCE,
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "is_stable": True,
+    },
+    "USDT": {
+        "pair": "USD",
+        "name": OKCOIN,
+        "is_stable": True,
+    },
+    "BUSD": {
+        "pair": "USDT",
+        "name": BINANCE,
+        "market_depth": {"exchange": BINANCE, "pairs": ["USDT"]},
+        "is_stable": True,
+    },
+    "DAI": {
+        "pair": "USD",
+        "name": COINBASE_PRO,
+        "is_stable": True,
+    },
 }
 
+# Settings validations
+
 # Check to make sure that ALL configured symbols must have an
 # exchange and pair referenced
 from xtcryptosignals.common.utils import get_coin_tokens  # noqa: E402
